@@ -580,11 +580,20 @@ class Package:
 
 	def add_to_paths2(self,loc,root):
 		for path in self.paths:
-			if q_usePackageRoot(self):
+#..................................fix found by Scott Koranda, fix suggested by Alain Roy.....
+			if len(path[1]) > 2 and path[1][:1]=='|' and path[1][-1]=='|':
+				pathval = path[1][1:-1]
+			elif q_usePackageRoot(self):
 				pathval = fncat(fncat(loc,root),path[1])
 			else:
 				pathval = path[1]
-			
+#..................................................................
+#				
+#			if q_usePackageRoot(self):
+#				pathval = fncat(fncat(loc,root),path[1])
+#			else:
+#				pathval = path[1]
+#			
 			if not os.environ.has_key(path[0]):
 				os.environ[path[0]] = pathval
 				if verbose: print 'Setting ['+path[0]+'] to ['+pathval+'].'
