@@ -50,15 +50,33 @@ def findLinuxVersion():
 			elif re.search('Fermi', line):
 				distro = 'fermi'
 
+#			if distro != None:
+#				version_match = re.search(r"\d+\.\d+", line)
+#				if version_match:
+#					version_string = line[version_match.start():version_match.end()]
+#					versions = ('linux-' + distro + '-' + version_string,
+#								'linux-'+distro)
+#				else:
+#					versions = ('', 'linux-'+distro)
+#				break
+#...replaced with Alain's new code as follows...
+#
 			if distro != None:
 				version_match = re.search(r"\d+\.\d+", line)
 				if version_match:
 					version_string = line[version_match.start():version_match.end()]
 					versions = ('linux-' + distro + '-' + version_string,
-								'linux-'+distro)
+					   'linux-'+distro)
 				else:
-					versions = ('', 'linux-'+distro)
+					version_match = re.search(r"\d+", line)
+					if version_match:
+						version_string = line[version_match.start():version_match.end()]
+						versions = ('linux-' + distro + '-' + version_string,
+							'linux-'+distro)
+					else:
+						versions = ('', 'linux-'+distro)
 				break
+
 	except IOError:
 		versions = ("", "")
 		
