@@ -1,4 +1,6 @@
-
+#
+#   Add missing test for .tar.Z suffix to fix Simon George's problem
+#
 import os,string
 from unix_base import *
 
@@ -9,9 +11,12 @@ def downloadroot(file):
 		root = ztar_root(file)
 	elif tail(file,'.tar'):
 		root = tar_root(file)
+	elif tail(file,'.tar.Z'):
+		root = tar_root(file)
 	else:
 		root = ''
-		
+	if not root=='' and verbose:
+		print 'Tarball ['+file+'] has root directory ['+root+'].'
 	return root
 
 def ztar_root(file):
