@@ -1,7 +1,7 @@
 
 import sys,os,string,commands,pwd
 
-version = '2.112'
+version = '2.116'
 
 def phas(d,x):
 	if d.count(x)>0: 
@@ -10,10 +10,8 @@ def phas(d,x):
 		return 0
 
 def python2():
-	if sys.version[0]=='2':
-		return 1
-	else:
-		return 0
+	if sys.version[0]=='2': return 1
+	else:                   return 0
 
 def shx(str):
 	if   shell()=='sh':
@@ -110,11 +108,13 @@ def ask_to_execute(command):
 	if switch('ask'):
 		while 1:
 			answer = raw_input('OK to execute: ['+command+'] (y or n)? ')
-			if answer == 'y' or answer == 'n': break
+			if answer == 'y' or answer == 'n' or answer=='skip': break
 		if answer=='y':
 #			os.system(command)
 #			return 1
 			return try_to_execute(command)
+		elif answer=='skip':
+			return 1
 		else:
 			print '['+command+'] not executed.'
 			sys.exit()
@@ -145,7 +145,24 @@ def is_root(): return not os.getuid()
 #	if user[:4] == 'root' or switch('rootpretend'): return 1
 #	else:                  return 0
 	
-def username(): return pwd.getpwuid(os.getuid())[0]
+def username():
+	try:
+		name = pwd.getpwuid(os.getuid())[0]
+	except KeyError:
+#--           Code from Scott Koranda, slightly modified. S.Y.
+		envVarList = ["USER","LOGNAME","LOGIN"]
+		got_one = 0
+		for var in envVarList:
+			try:
+				name = os.environ[var]
+				got_one = 1
+			except KeyError:
+				pass
+		if not got_one: 
+			print "Warning: Can't determine username, setting to username = 'unknown'..."
+			name = 'unknown'
+	return name
+ 
 #	pipe = os.popen('whoami')
 #	user = pipe.read()
 #	del pipe
